
muscima
=======

The ``muscima`` package implements a data model for the MUSCIMA++
dataset of music notation. The dataset itself is available for download
here:

[MUSCIMA++ v0.9](https://ufal.mff.cuni.cz/jan-hajic-jr/MUSCIMA++_v0.9.zip)

**Current dataset version: 0.9**

**Current package version: 0.3.2**

The package should work with both Python 2.7 and Python 3.5,
although the doctest-based test suite only works on Python 3.

The package is distributed under the MIT license (see LICENSE file).

[The documentation is online, including a tutorial, here.](https://muscima.readthedocs.io)


Getting started
---------------

1. Install this package: ``pip install muscima``
2. Download the [MUSCIMA++ dataset](https://ufal.mff.cuni.cz/jan-hajic-jr/MUSCIMA++_v0.9.zip).
3. Run through the tutorial.

